@@ -85,7 +85,6 @@ function configure_sahara {
         iniset $SAHARA_CONF_FILE oslo_messaging_notifications driver "messaging"
     fi
 
-    iniset $SAHARA_CONF_FILE DEFAULT verbose True
     iniset $SAHARA_CONF_FILE DEFAULT debug $ENABLE_DEBUG_LOG_LEVEL
 
     iniset $SAHARA_CONF_FILE DEFAULT plugins $SAHARA_ENABLED_PLUGINS
@@ -95,7 +94,7 @@ function configure_sahara {
 
     if is_service_enabled neutron; then
         iniset $SAHARA_CONF_FILE DEFAULT use_neutron true
-
+        iniset $SAHARA_CONF_FILE neutron endpoint_type $SAHARA_ENDPOINT_TYPE
         if is_ssl_enabled_service "neutron" \
             || is_service_enabled tls-proxy; then
             iniset $SAHARA_CONF_FILE neutron ca_file $SSL_BUNDLE_FILE
@@ -107,22 +106,32 @@ function configure_sahara {
     if is_ssl_enabled_service "heat" || is_service_enabled tls-proxy; then
         iniset $SAHARA_CONF_FILE heat ca_file $SSL_BUNDLE_FILE
     fi
+    iniset $SAHARA_CONF_FILE heat endpoint_type $SAHARA_ENDPOINT_TYPE
 
     if is_ssl_enabled_service "cinder" || is_service_enabled tls-proxy; then
         iniset $SAHARA_CONF_FILE cinder ca_file $SSL_BUNDLE_FILE
     fi
+    iniset $SAHARA_CONF_FILE cinder endpoint_type $SAHARA_ENDPOINT_TYPE
 
     if is_ssl_enabled_service "nova" || is_service_enabled tls-proxy; then
         iniset $SAHARA_CONF_FILE nova ca_file $SSL_BUNDLE_FILE
     fi
+    iniset $SAHARA_CONF_FILE nova endpoint_type $SAHARA_ENDPOINT_TYPE
 
     if is_ssl_enabled_service "swift" || is_service_enabled tls-proxy; then
         iniset $SAHARA_CONF_FILE swift ca_file $SSL_BUNDLE_FILE
     fi
+    iniset $SAHARA_CONF_FILE swift endpoint_type $SAHARA_ENDPOINT_TYPE
 
     if is_ssl_enabled_service "key" || is_service_enabled tls-proxy; then
         iniset $SAHARA_CONF_FILE keystone ca_file $SSL_BUNDLE_FILE
     fi
+    iniset $SAHARA_CONF_FILE keystone endpoint_type $SAHARA_ENDPOINT_TYPE
+
+    if is_ssl_enabled_service "glance" || is_service_enabled tls-proxy; then
+        iniset $SAHARA_CONF_FILE glance ca_file $SSL_BUNDLE_FILE
+    fi
+    iniset $SAHARA_CONF_FILE glance endpoint_type $SAHARA_ENDPOINT_TYPE
 
     # Register SSL certificates if provided
     if is_ssl_enabled_service sahara; then
@@ -148,6 +157,7 @@ function configure_sahara {
         # Enable distributed periodic tasks
         iniset $SAHARA_CONF_FILE DEFAULT periodic_coordinator_backend_url\
             $SAHARA_PERIODIC_COORDINATOR_URL
+        sudo pip install tooz[zookeeper]
     fi
 
     recreate_database sahara
@@ -198,6 +208,14 @@ function start_sahara {
     fi
 }
 
+# configure_tempest_for_sahara() - Tune Tempest configuration for Sahara
+function configure_tempest_for_sahara {
+    if is_service_enabled tempest; then
+        iniset $TEMPEST_CONFIG service_available sahara True
+        iniset $TEMPEST_CONFIG data-processing-feature-enabled plugins $SAHARA_ENABLED_PLUGINS
+    fi
+}
+
 # stop_sahara() - Stop running processes
 function stop_sahara {
     # Kill the Sahara screen windows
@@ -232,6 +250,9 @@ if is_service_enabled sahara; then
     elif [[ "$1" == "stack" && "$2" == "extra" ]]; then
         echo_summary "Initializing sahara"
         start_sahara
+    elif [[ "$1" == "stack" && "$2" == "test-config" ]]; then
+        echo_summary "Configuring tempest"
+        configure_tempest_for_sahara
     fi
 
     if [[ "$1" == "unstack" ]]; then
