@@ -13,23 +13,18 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo_log import log as logging
-
 from sahara.conductor import resource as res
 from sahara.plugins.cdh import commands as cmd
 from sahara.plugins.cdh import plugin_utils as pu
-from sahara.plugins.cdh.v5_4_0 import config_helper
-from sahara.plugins.cdh.v5_4_0 import db_helper
+from sahara.plugins.cdh.v5_5_0 import config_helper
+from sahara.plugins.cdh.v5_5_0 import db_helper
 from sahara.plugins import utils as u
 
 
-LOG = logging.getLogger(__name__)
-
-
-class PluginUtilsV540(pu.AbstractPluginUtils):
+class PluginUtilsV550(pu.AbstractPluginUtils):
 
     def __init__(self):
-        self.c_helper = config_helper.ConfigHelperV540()
+        self.c_helper = config_helper.ConfigHelperV550()
         self.db_helper = db_helper
 
     def get_role_name(self, instance, service):
@@ -47,6 +42,7 @@ class PluginUtilsV540(pu.AbstractPluginUtils):
             'IMPALAD': 'ID',
             'JOBHISTORY': 'JS',
             'JOURNALNODE': 'JN',
+            'KAFKA_BROKER': 'KB',
             'KMS': 'KMS',
             'MASTER': 'M',
             'NAMENODE': 'NN',
@@ -102,6 +98,9 @@ class PluginUtilsV540(pu.AbstractPluginUtils):
     def get_stdb_rm(self, cluster):
         return u.get_instance(cluster, 'YARN_STANDBYRM')
 
+    def get_kafka_brokers(self, cluster):
+        return u.get_instances(cluster, 'KAFKA_BROKER')
+
     def convert_process_configs(self, configs):
         p_dict = {
             "CLOUDERA": ['MANAGER'],
@@ -129,9 +128,10 @@ class PluginUtilsV540(pu.AbstractPluginUtils):
             "SOLR": ['SOLR_SERVER'],
             "SQOOP": ['SQOOP_SERVER'],
             "KMS": ['KMS'],
-            'YARN_GATEWAY': ['YARN_GATEWAY'],
-            'HDFS_GATEWAY': ['HDFS_GATEWAY'],
-            "JOURNALNODE": ['JOURNALNODE']
+            "YARN_GATEWAY": ['YARN_GATEWAY'],
+            "HDFS_GATEWAY": ['HDFS_GATEWAY'],
+            "JOURNALNODE": ['JOURNALNODE'],
+            "KAFKA": ['KAFKA_BROKER']
         }
         if isinstance(configs, res.Resource):
             configs = configs.to_dict()
@@ -149,7 +149,7 @@ class PluginUtilsV540(pu.AbstractPluginUtils):
             self.db_helper.create_sentry_database(cluster, r)
 
     def _configure_repo_from_inst(self, instance):
-        super(PluginUtilsV540, self)._configure_repo_from_inst(instance)
+        super(PluginUtilsV550, self)._configure_repo_from_inst(instance)
 
         cluster = instance.cluster
         with instance.remote() as r:
