@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -15,9 +15,9 @@
 
 from sahara.i18n import _
 from sahara.plugins.cdh import cloudera_utils as cu
-from sahara.plugins.cdh.v5_5_0 import config_helper
-from sahara.plugins.cdh.v5_5_0 import plugin_utils as pu
-from sahara.plugins.cdh.v5_5_0 import validation
+from sahara.plugins.cdh.v5_7_0 import config_helper
+from sahara.plugins.cdh.v5_7_0 import plugin_utils as pu
+from sahara.plugins.cdh.v5_7_0 import validation
 from sahara.swift import swift_helper
 from sahara.utils import cluster_progress_ops as cpo
 from sahara.utils import configs as s_cfg
@@ -39,11 +39,12 @@ SQOOP_SERVICE_TYPE = 'SQOOP'
 KS_INDEXER_SERVICE_TYPE = 'KS_INDEXER'
 IMPALA_SERVICE_TYPE = 'IMPALA'
 KMS_SERVICE_TYPE = 'KMS'
+KAFKA_SERVICE_TYPE = 'KAFKA'
 
-c_helper = config_helper.ConfigHelperV550()
+c_helper = config_helper.ConfigHelperV570()
 
 
-class ClouderaUtilsV550(cu.ClouderaUtils):
+class ClouderaUtilsV570(cu.ClouderaUtils):
     FLUME_SERVICE_NAME = 'flume01'
     SOLR_SERVICE_NAME = 'solr01'
     SQOOP_SERVICE_NAME = 'sqoop01'
@@ -51,13 +52,14 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
     IMPALA_SERVICE_NAME = 'impala01'
     SENTRY_SERVICE_NAME = 'sentry01'
     KMS_SERVICE_NAME = 'kms01'
+    KAFKA_SERVICE_NAME = 'kafka01'
     CM_API_VERSION = 8
     NAME_SERVICE = 'nameservice01'
 
     def __init__(self):
         cu.ClouderaUtils.__init__(self)
-        self.pu = pu.PluginUtilsV550()
-        self.validator = validation.ValidatorV550
+        self.pu = pu.PluginUtilsV570()
+        self.validator = validation.ValidatorV570
 
     def get_service_by_role(self, role, cluster=None, instance=None):
         cm_cluster = None
@@ -86,8 +88,10 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
             return cm_cluster.get_service(self.HDFS_SERVICE_NAME)
         elif role in ['YARN_STANDBYRM']:
             return cm_cluster.get_service(self.YARN_SERVICE_NAME)
+        elif role in ['KAFKA_BROKER']:
+            return cm_cluster.get_service(self.KAFKA_SERVICE_NAME)
         else:
-            return super(ClouderaUtilsV550, self).get_service_by_role(
+            return super(ClouderaUtilsV570, self).get_service_by_role(
                 role, cluster, instance)
 
     @cpo.event_wrapper(
@@ -141,6 +145,9 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
         if self.pu.get_kms(cluster):
             cm_cluster.create_service(self.KMS_SERVICE_NAME,
                                       KMS_SERVICE_TYPE)
+        if len(self.pu.get_kafka_brokers(cluster)) > 0:
+            cm_cluster.create_service(self.KAFKA_SERVICE_NAME,
+                                      KAFKA_SERVICE_TYPE)
 
     def await_agents(self, cluster, instances):
         self._await_agents(cluster, instances, c_helper.AWAIT_AGENTS_TIMEOUT)
@@ -221,6 +228,10 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
             kms = cm_cluster.get_service(self.KMS_SERVICE_NAME)
             kms.update_config(self._get_configs(KMS_SERVICE_TYPE,
                                                 cluster=cluster))
+        if len(self.pu.get_kafka_brokers(cluster)) > 0:
+            kafka = cm_cluster.get_service(self.KAFKA_SERVICE_NAME)
+            kafka.update_config(self._get_configs(KAFKA_SERVICE_TYPE,
+                                                  cluster=cluster))
 
     def _get_configs(self, service, cluster=None, instance=None):
         def get_hadoop_dirs(mount_points, suffix):
@@ -364,10 +375,15 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
                         self.pu.db_helper.get_sentry_db_password(cluster)
                 }
             }
-
+            kafka_confs = {
+                'KAFKA': {
+                    'zookeeper_service': self.ZOOKEEPER_SERVICE_NAME
+                }
+            }
             all_confs = s_cfg.merge_configs(all_confs, hue_confs)
             all_confs = s_cfg.merge_configs(all_confs, hive_confs)
             all_confs = s_cfg.merge_configs(all_confs, sentry_confs)
+            all_confs = s_cfg.merge_configs(all_confs, kafka_confs)
             all_confs = s_cfg.merge_configs(all_confs, cluster.cluster_configs)
 
         if instance:
@@ -390,7 +406,11 @@ class ClouderaUtilsV550(cu.ClouderaUtils):
                 },
                 'NODEMANAGER': {
                     'yarn_nodemanager_local_dirs':
-                        get_hadoop_dirs(paths, '/yarn/local')
+                        get_hadoop_dirs(paths, '/yarn/local'),
+                    'container_executor_allowed_system_users':
+                        "nobody,impala,hive,llama,hdfs,yarn,mapred,"
+                        "spark,oozie",
+                    "container_executor_banned_users": "bin"
                 },
                 'SERVER': {
                     'maxSessionTimeout': 60000
