@@ -1,4 +1,4 @@
-# Copyright (c) 2015 Intel Corporation.
+# Copyright (c) 2016 Mirantis Inc.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -18,17 +18,17 @@ from sahara.utils import files
 
 
 def get_hive_db_password(cluster):
-    return dh.get_password_from_db(cluster, dh.HIVE_DB_PASSWORD)
+    return dh.get_password_from_db(cluster, 'hive_db_password')
 
 
 def get_sentry_db_password(cluster):
-    return dh.get_password_from_db(cluster, dh.SENTRY_DB_PASSWORD)
+    return dh.get_password_from_db(cluster, 'sentry_db_password')
 
 
 def create_hive_database(cluster, remote):
     db_password = get_hive_db_password(cluster)
     create_db_script = files.get_file_text(
-        'plugins/cdh/v5_4_0/resources/create_hive_db.sql')
+        'plugins/cdh/v5_7_0/resources/create_hive_db.sql')
     create_db_script = create_db_script % db_password
     dh.remote_execute_db_script(remote, create_db_script)
 
@@ -36,6 +36,6 @@ def create_hive_database(cluster, remote):
 def create_sentry_database(cluster, remote):
     db_password = get_sentry_db_password(cluster)
     create_db_script = files.get_file_text(
-        'plugins/cdh/v5_4_0/resources/create_sentry_db.sql')
+        'plugins/cdh/v5_7_0/resources/create_sentry_db.sql')
     create_db_script = create_db_script % db_password
     dh.remote_execute_db_script(remote, create_db_script)
