@@ -14,7 +14,6 @@
 
 
 import abc
-import os
 
 from oslo_log import log as logging
 import six
@@ -26,6 +25,7 @@ from sahara.i18n import _LI
 from sahara.i18n import _LW
 import sahara.plugins.mapr.abstract.configurer as ac
 from sahara.plugins.mapr.domain import distro as d
+from sahara.plugins.mapr.domain import service as srvc
 import sahara.plugins.mapr.services.management.management as mng
 import sahara.plugins.mapr.services.mapreduce.mapreduce as mr
 from sahara.plugins.mapr.services.maprfs import maprfs
@@ -33,12 +33,12 @@ from sahara.plugins.mapr.services.mysql import mysql
 import sahara.plugins.mapr.services.yarn.yarn as yarn
 from sahara.plugins.mapr.util import event_log as el
 import sahara.plugins.mapr.util.general as util
+import sahara.plugins.mapr.util.password_utils as pu
 import sahara.utils.files as files
 
 LOG = logging.getLogger(__name__)
 conductor = conductor.API
 
-_MAPR_HOME = '/opt/mapr'
 _JAVA_HOME = '/usr/java/jdk1.7.0_51'
 _CONFIGURE_SH_TIMEOUT = 600
 _SET_MODE_CMD = 'maprcli cluster mapreduce set -mode '
@@ -49,7 +49,6 @@ INSTALL_SCALA_SCRIPT = 'plugins/mapr/resources/install_scala.sh'
 INSTALL_MYSQL_CLIENT = 'plugins/mapr/resources/install_mysql_client.sh'
 ADD_MAPR_REPO_SCRIPT = 'plugins/mapr/resources/add_mapr_repo.sh'
 ADD_SECURITY_REPO_SCRIPT = 'plugins/mapr/resources/add_security_repos.sh'
-ADD_MAPR_USER = 'plugins/mapr/resources/add_mapr_user.sh'
 
 SERVICE_INSTALL_PRIORITY = [
     mng.Management(),
@@ -69,7 +68,6 @@ class BaseConfigurer(ac.AbstractConfigurer):
         self._install_mapr_repo(cluster_context, instances)
         if not cluster_context.is_prebuilt:
             self._prepare_bare_image(cluster_context, instances)
-        self.configure_general_environment(cluster_context, instances)
         self._install_services(cluster_context, instances)
         if cluster_context.is_node_aware:
             self._configure_topology(cluster_context, instances)
@@ -77,6 +75,7 @@ class BaseConfigurer(ac.AbstractConfigurer):
         self._configure_services(cluster_context, instances)
         self._configure_sh_cluster(cluster_context, instances)
         self._set_cluster_mode(cluster_context, instances)
+        self._post_configure_services(cluster_context, instances)
         self._write_config_files(cluster_context, instances)
         self._configure_environment(cluster_context, instances)
         self._update_cluster_info(cluster_context)
@@ -101,14 +100,8 @@ class BaseConfigurer(ac.AbstractConfigurer):
             service.configure(cluster_context, instances)
 
     def _install_services(self, cluster_context, instances):
-        step_name_template = _("Install %s service")
         for service in self._service_install_sequence(cluster_context):
-            # Add own provision step for each service
-            step_name = step_name_template % service.ui_name
-            decorator = el.provision_step(step_name, 0, 1)
-            install_service = decorator(service.install)
-
-            install_service(cluster_context, instances)
+            service.install(cluster_context, instances)
 
     def _service_install_sequence(self, cluster_context):
         def key(service):
@@ -174,16 +167,16 @@ class BaseConfigurer(ac.AbstractConfigurer):
         util.execute_on_instances(instances, install_java)
 
     @el.provision_step(_("Configure cluster topology"))
-    def _configure_topology(self, context, instances):
+    def _configure_topology(self, cluster_context, instances):
         LOG.debug("Configuring cluster topology")
 
-        topology_map = context.topology_map
+        topology_map = cluster_context.topology_map
         topology_map = ("%s %s" % item for item in six.iteritems(topology_map))
         topology_map = "\n".join(topology_map) + "\n"
 
-        data_path = "%s/topology.data" % context.mapr_home
+        data_path = "%s/topology.data" % cluster_context.mapr_home
         script = files.get_file_text(_TOPO_SCRIPT)
-        script_path = '%s/topology.sh' % context.mapr_home
+        script_path = '%s/topology.sh' % cluster_context.mapr_home
 
         @el.provision_event()
         def write_topology_data(instance):
@@ -202,9 +195,8 @@ class BaseConfigurer(ac.AbstractConfigurer):
         @el.provision_event()
         def write_config_files(instance, config_files):
             for file in config_files:
-                util.mkdir(instance, os.path.dirname(file.path), owner="root")
                 util.write_file(instance, file.path, file.data, mode=file.mode,
-                                owner="root")
+                                owner="mapr")
 
         node_groups = util.unique_list(instances, lambda i: i.node_group)
         for node_group in node_groups:
@@ -216,6 +208,7 @@ class BaseConfigurer(ac.AbstractConfigurer):
         LOG.debug("Config files are successfully written")
 
     def _configure_environment(self, cluster_context, instances):
+        self.configure_general_environment(cluster_context, instances)
         self._post_install_services(cluster_context, instances)
 
     def _configure_database(self, cluster_context, instances):
@@ -233,9 +226,12 @@ class BaseConfigurer(ac.AbstractConfigurer):
 
     def _update_cluster_info(self, cluster_context):
         LOG.debug('Updating UI information.')
-        info = {}
+        info = {'Admin user credentials': {'Username': 'mapr',
+                                           'Password': pu.get_mapr_password
+                                           (cluster_context.cluster)}}
         for service in cluster_context.cluster_services:
-            for title, node_process, url_template in service.ui_info:
+            for title, node_process, ui_info in (service.get_ui_info
+                                                 (cluster_context)):
                 removed = cluster_context.removed_instances(node_process)
                 instances = cluster_context.get_instances(node_process)
                 instances = [i for i in instances if i not in removed]
@@ -248,27 +244,28 @@ class BaseConfigurer(ac.AbstractConfigurer):
                 for index, instance in enumerate(instances, start=1):
                     args = {"title": title, "index": index}
                     display_name = display_name_template % args
-                    url = url_template % instance.management_ip
-                    info.update({display_name: {"WebUI": url}})
+                    data = ui_info.copy()
+                    data[srvc.SERVICE_UI] = (data[srvc.SERVICE_UI] %
+                                             instance.get_ip_or_dns_name())
+                    info.update({display_name: data})
 
         ctx = context.ctx()
         conductor.cluster_update(ctx, cluster_context.cluster, {'info': info})
 
     def configure_general_environment(self, cluster_context, instances=None):
         LOG.debug('Executing post configure hooks')
+        mapr_user_pass = pu.get_mapr_password(cluster_context.cluster)
 
         if not instances:
             instances = cluster_context.get_instances()
 
-        def create_user(instance):
-            return util.run_script(instance, ADD_MAPR_USER, "root")
-
         def set_user_password(instance):
             LOG.debug('Setting password for user "mapr"')
             if self.mapr_user_exists(instance):
                 with instance.remote() as r:
                     r.execute_command(
-                        'echo "%s:%s"|chpasswd' % ('mapr', 'mapr'),
+                        'echo "%s:%s"|chpasswd' %
+                        ('mapr', mapr_user_pass),
                         run_as_root=True)
             else:
                 LOG.warning(_LW('User "mapr" does not exists'))
@@ -276,15 +273,17 @@ class BaseConfigurer(ac.AbstractConfigurer):
         def create_home_mapr(instance):
             target_path = '/home/mapr'
             LOG.debug("Creating home directory for user 'mapr'")
-            args = {'path': target_path}
-            cmd = 'mkdir -p %(path)s && chown mapr:mapr %(path)s' % args
+            args = {'path': target_path,
+                    'user': 'mapr',
+                    'group': 'mapr'}
+            cmd = ('mkdir -p %(path)s && chown %(user)s:%(group)s %(path)s'
+                   % args)
             if self.mapr_user_exists(instance):
                 with instance.remote() as r:
                     r.execute_command(cmd, run_as_root=True)
             else:
                 LOG.warning(_LW('User "mapr" does not exists'))
 
-        util.execute_on_instances(instances, create_user)
         util.execute_on_instances(instances, set_user_password)
         util.execute_on_instances(instances, create_home_mapr)
 
@@ -310,10 +309,11 @@ class BaseConfigurer(ac.AbstractConfigurer):
         LOG.debug('Executing configure.sh successfully completed')
 
     @el.provision_event(instance_reference=2)
-    def _configure_sh_instance(self, context, instance, command, specs):
+    def _configure_sh_instance(self, cluster_context, instance, command,
+                               specs):
         if not self.mapr_user_exists(instance):
             command += ' --create-user'
-        if context.check_for_process(instance, mng.METRICS):
+        if cluster_context.check_for_process(instance, mng.METRICS):
             command += (' -d %(host)s:%(port)s -du %(user)s -dp %(password)s '
                         '-ds %(db_name)s') % specs
         with instance.remote() as r:
@@ -335,15 +335,17 @@ class BaseConfigurer(ac.AbstractConfigurer):
     def mapr_user_exists(self, instance):
         with instance.remote() as r:
             ec, __ = r.execute_command(
-                "id -u mapr", run_as_root=True, raise_when_error=False)
+                "id -u %s" %
+                'mapr', run_as_root=True, raise_when_error=False)
         return ec == 0
 
-    def post_start(self, c_context, instances=None):
-        instances = instances or c_context.get_instances()
+    def post_start(self, cluster_context, instances=None):
+        instances = instances or cluster_context.get_instances()
         LOG.debug('Executing service post start hooks')
-        for service in c_context.cluster_services:
-            updated = c_context.filter_instances(instances, service=service)
-            service.post_start(c_context, updated)
+        for service in cluster_context.cluster_services:
+            updated = cluster_context.filter_instances(instances,
+                                                       service=service)
+            service.post_start(cluster_context, updated)
         LOG.info(_LI('Post start hooks successfully executed'))
 
     @el.provision_step(_("Set cluster mode"))
@@ -356,7 +358,8 @@ class BaseConfigurer(ac.AbstractConfigurer):
 
         @el.provision_event()
         def set_cluster_mode(instance):
-            return util.execute_command([instance], command, run_as="mapr")
+            return util.execute_command([instance], command,
+                                        run_as='mapr')
 
         util.execute_on_instances(instances, set_cluster_mode)
 
@@ -371,10 +374,11 @@ class BaseConfigurer(ac.AbstractConfigurer):
 
         util.execute_on_instances(instances, install_mapr_repos)
 
-    def _update_services(self, c_context, instances):
-        for service in c_context.cluster_services:
-            updated = c_context.filter_instances(instances, service=service)
-            service.update(c_context, updated)
+    def _update_services(self, cluster_context, instances):
+        for service in cluster_context.cluster_services:
+            updated = cluster_context.filter_instances(instances,
+                                                       service=service)
+            service.update(cluster_context, updated)
 
     def _restart_services(self, cluster_context):
         restart = cluster_context.should_be_restarted
@@ -386,3 +390,7 @@ class BaseConfigurer(ac.AbstractConfigurer):
         for service in cluster_context.cluster_services:
             service.post_configure_sh(cluster_context, instances)
         LOG.info(_LI('Post configure.sh hooks successfully executed'))
+
+    def _post_configure_services(self, cluster_context, instances):
+        for service in cluster_context.cluster_services:
+            service.post_configure(cluster_context, instances)
