@@ -44,6 +44,7 @@ class BaseClusterContext(cc.AbstractClusterContext):
     def __init__(self, cluster, version_handler, added=None, removed=None):
         self._cluster = cluster
         self._distro = None
+        self._distro_version = None
         self._all_services = version_handler.get_services()
         self._required_services = version_handler.get_required_services()
         self._cluster_services = None
@@ -153,6 +154,12 @@ class BaseClusterContext(cc.AbstractClusterContext):
             self._some_instance = self.cluster.node_groups[0].instances[0]
         return self._some_instance
 
+    @property
+    def distro_version(self):
+        if not self._distro_version:
+            self._distro_version = distro.get_version(self.some_instance)
+        return self._distro_version
+
     @property
     def distro(self):
         if not self._distro:
@@ -200,6 +207,20 @@ class BaseClusterContext(cc.AbstractClusterContext):
         else:
             return config.default_value
 
+    def get_node_processes(self):
+        node_processes = []
+        for ng in self.cluster.node_groups:
+            for np in ng.node_processes:
+                if np not in node_processes:
+                    node_processes.append(self.get_node_process_by_name(np))
+        return node_processes
+
+    def get_node_process_by_name(self, name):
+        for service in self.cluster_services:
+            for node_process in service.node_processes:
+                if node_process.ui_name == name:
+                    return node_process
+
     def get_instances(self, node_process=None):
         if node_process is not None:
             node_process = su.get_node_process_name(node_process)
