@@ -13,18 +13,24 @@
 # under the License.
 
 
+from oslo_log import log as logging
 from oslo_serialization import jsonutils as json
 import six
 
 import sahara.exceptions as e
 from sahara.i18n import _
 import sahara.plugins.exceptions as ex
+from sahara.plugins.mapr.util import commands as cmd
 from sahara.plugins.mapr.util import event_log as el
 from sahara.plugins.mapr.util import general as g
 from sahara.plugins.mapr.util import service_utils as su
 import sahara.plugins.provisioning as p
 from sahara.utils import files as files
 
+LOG = logging.getLogger(__name__)
+
+SERVICE_UI = 'Web UI'
+
 _INSTALL_PACKAGES_TIMEOUT = 3600
 
 
@@ -62,10 +68,6 @@ class Service(object):
     def dependencies(self):
         return self._dependencies
 
-    @property
-    def ui_info(self):
-        return self._ui_info
-
     @property
     def cluster_defaults(self):
         return self._cluster_defaults
@@ -78,22 +80,34 @@ class Service(object):
     def validation_rules(self):
         return self._validation_rules
 
+    def get_ui_info(self, cluster_context):
+        return self._ui_info
+
     def install(self, cluster_context, instances):
-        g.execute_on_instances(instances, self._install_packages_on_instance,
-                               cluster_context)
+        service_instances = cluster_context.filter_instances(instances,
+                                                             service=self)
+
+        @el.provision_step(_("Install %s service") % self.ui_name,
+                           cluster_context_reference=0, instances_reference=1)
+        def _install(_context, _instances):
+            g.execute_on_instances(_instances,
+                                   self._install_packages_on_instance,
+                                   _context)
+
+        _install(cluster_context, service_instances)
 
     @el.provision_event(instance_reference=1)
     def _install_packages_on_instance(self, instance, cluster_context):
         processes = [p for p in self.node_processes if
                      p.ui_name in instance.node_group.node_processes]
         if processes is not None and len(processes) > 0:
-            packages = self._get_packages(processes)
+            packages = self._get_packages(cluster_context, processes)
             cmd = cluster_context.distro.create_install_cmd(packages)
             with instance.remote() as r:
                 r.execute_command(cmd, run_as_root=True,
                                   timeout=_INSTALL_PACKAGES_TIMEOUT)
 
-    def _get_packages(self, node_processes):
+    def _get_packages(self, cluster_context, node_processes):
         result = []
 
         result += self.dependencies
@@ -101,6 +115,13 @@ class Service(object):
 
         return result
 
+    def _set_service_dir_owner(self, cluster_context, instances):
+        service_instances = cluster_context.filter_instances(instances,
+                                                             service=self)
+        LOG.debug("Changing %s service dir owner" % self.ui_name)
+        for instance in service_instances:
+            cmd.chown(instance, 'mapr:mapr', self.service_dir(cluster_context))
+
     def post_install(self, cluster_context, instances):
         pass
 
@@ -220,3 +241,6 @@ class Service(object):
 
     def post_configure_sh(self, cluster_context, instances):
         pass
+
+    def post_configure(self, cluster_context, instances):
+        pass
