@@ -43,8 +43,8 @@ class MapReduce(s.Service):
         self._version = '0.20.2'
         self._node_processes = [JOB_TRACKER, TASK_TRACKER]
         self._ui_info = [
-            ('JobTracker', JOB_TRACKER, 'http://%s:50030'),
-            ('TaskTracker', TASK_TRACKER, 'http://%s:50060'),
+            ('JobTracker', JOB_TRACKER, {s.SERVICE_UI: 'http://%s:50030'}),
+            ('TaskTracker', TASK_TRACKER, {s.SERVICE_UI: 'http://%s:50060'}),
         ]
         self._validation_rules = [
             vu.at_least(1, JOB_TRACKER),
@@ -52,7 +52,7 @@ class MapReduce(s.Service):
         ]
         self._cluster_defaults = ['mapreduce-cluster.json']
 
-    def _get_packages(self, node_processes):
+    def _get_packages(self, cluster_context, node_processes):
         result = []
 
         result += self.dependencies
@@ -78,9 +78,9 @@ class MapReduce(s.Service):
 
         return [core_site, mapred_site]
 
-    def _get_core_site_props(self, context):
+    def _get_core_site_props(self, cluster_context):
         result = {}
-        if context.is_node_aware:
+        if cluster_context.is_node_aware:
             result.update(self._get_core_site_node_aware_props())
         for conf in swift_helper.get_swift_configs():
             result[conf['name']] = conf['value']
@@ -97,9 +97,9 @@ class MapReduce(s.Service):
         })
         return result
 
-    def _get_mapred_site_props(self, context):
+    def _get_mapred_site_props(self, cluster_context):
         result = {}
-        if context.is_node_aware:
+        if cluster_context.is_node_aware:
             result.update(self._get_mapred_site_node_aware_props())
         result.update({
             'jobtracker.thrift.address': '0.0.0.0:9290',
