@@ -26,14 +26,14 @@ from sahara.plugins.mapr.services.management import management as mng
 from sahara.plugins.mapr.services.maprfs import maprfs
 from sahara.plugins.mapr.services.oozie import oozie
 from sahara.plugins.mapr.services.pig import pig
+from sahara.plugins.mapr.services.sentry import sentry
 from sahara.plugins.mapr.services.spark import spark
 from sahara.plugins.mapr.services.sqoop import sqoop2
 from sahara.plugins.mapr.services.swift import swift
 from sahara.plugins.mapr.services.yarn import yarn
-import sahara.plugins.mapr.versions.v5_1_0_mrv2.context as c
+import sahara.plugins.mapr.versions.v5_2_0_mrv2.context as c
 
-
-version = "5.1.0.mrv2"
+version = "5.2.0.mrv2"
 
 
 class VersionHandler(bvh.BaseVersionHandler):
@@ -47,32 +47,23 @@ class VersionHandler(bvh.BaseVersionHandler):
             oozie.Oozie(),
         ]
         self._services = [
-            hive.HiveV013(),
-            hive.HiveV10(),
             hive.HiveV12(),
-            impala.ImpalaV141(),
-            pig.PigV014(),
             pig.PigV015(),
+            impala.ImpalaV250(),
             flume.FlumeV16(),
-            flume.FlumeV15(),
             sqoop2.Sqoop2(),
-            mahout.MahoutV010(),
-            oozie.OozieV410(),
+            mahout.MahoutV012(),
             oozie.OozieV420(),
-            hue.HueV370(),
-            hue.HueV381(),
             hue.HueV390(),
-            hbase.HBaseV0989(),
-            hbase.HBaseV09812(),
-            drill.DrillV11(),
-            drill.DrillV12(),
-            drill.DrillV14(),
+            hbase.HBaseV111(),
+            drill.DrillV16(),
             yarn.YARNv270(),
             maprfs.MapRFS(),
             mng.Management(),
             httpfs.HttpFS(),
             swift.Swift(),
-            spark.SparkOnYarn()
+            sentry.SentryV16(),
+            spark.SparkOnYarnV161(),
         ]
 
     def get_context(self, cluster, added=None, removed=None):
