@@ -13,6 +13,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import copy
 
 from sahara import exceptions as ex
 from sahara.i18n import _
@@ -29,6 +30,17 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
     def get_configs(self, hadoop_version):
         pass
 
+    @plugins_base.required_with_default
+    def get_labels(self):
+        versions = self.get_versions()
+        default = {'enabled': {'status': True}}
+        return {
+            'plugin_labels': copy.deepcopy(default),
+            'version_labels': {
+                version: copy.deepcopy(default) for version in versions
+            }
+        }
+
     @plugins_base.required
     def get_node_processes(self, hadoop_version):
         pass
@@ -82,8 +94,67 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
         pass
 
     @plugins_base.optional
-    def convert(self, config, plugin_name, version, template_name,
-                cluster_template_create):
+    def get_image_arguments(self, hadoop_version):
+        """Gets the argument set taken by the plugin's image generator
+
+        Note: If the plugin can generate or validate an image but takes no
+        arguments, please return an empty sequence rather than NotImplemented
+        for all versions that support image generation or validation. This is
+        used as a flag to determine whether the plugin has implemented this
+        optional feature.
+
+        :returns: A sequence with items of type
+            sahara.plugins.images.ImageArgument
+        """
+        return NotImplemented
+
+    @plugins_base.optional
+    def pack_image(self, hadoop_version, remote,
+                   reconcile=True, image_arguments=None):
+        """Packs an image for registration in Glance and use by Sahara
+
+        :param remote: A remote (usually of type
+            sahara.cli.image_pack.api.ImageRemote) that serves as a handle to
+            the image to modify. Note that this image will be modified
+            in-place, not copied.
+        :param reconcile: If set to False, this method will only test to
+            ensure that the image already meets the plugin's requirements.
+            This can be used to test images without modification. If set to
+            True per the default, this method will modify the image if any
+            requirements are not met.
+        :param image_arguments: A dict of image argument name to argument
+            value.
+        :raises: sahara.plugins.exceptions.ImageValidationError: If the method
+            fails to modify the image to specification (if reconcile is True),
+            or if the method finds that the image does not meet the
+            specification (if reconcile is False).
+        :raises: sahara.plugins.exceptions.ImageValidationSpecificationError:
+            If the specification for image generation or validation is itself
+            in error and cannot be executed without repair.
+        """
+        pass
+
+    @plugins_base.optional
+    def validate_images(self, cluster, reconcile=True, image_arguments=None):
+        """Validates the image to be used by a cluster.
+
+        :param cluster: The object handle to a cluster which has active
+            instances ready to generate remote handles.
+        :param reconcile: If set to False, this method will only test to
+            ensure that the image already meets the plugin's requirements.
+            This can be used to test images without modification. If set to
+            True per the default, this method will modify the image if any
+            requirements are not met.
+        :param image_arguments: A dict of image argument name to argument
+            value.
+        :raises: sahara.plugins.exceptions.ImageValidationError: If the method
+            fails to modify the image to specification (if reconcile is True),
+            or if the method finds that the image does not meet the
+            specification (if reconcile is False).
+        :raises: sahara.plugins.exceptions.ImageValidationSpecificationError:
+            If the specification for image generation or validation is itself
+            in error and cannot be executed without repair.
+        """
         pass
 
     @plugins_base.required_with_default
@@ -105,6 +176,14 @@ class ProvisioningPluginBase(plugins_base.PluginInterface):
             common.extend(plugin_specific_configs)
         return common
 
+    def get_version_details(self, version):
+        details = {}
+        configs = self.get_all_configs(version)
+        details['configs'] = [c.dict for c in configs]
+        details['node_processes'] = self.get_node_processes(version)
+        details['required_image_tags'] = self.get_required_image_tags(version)
+        return details
+
     def to_dict(self):
         res = super(ProvisioningPluginBase, self).to_dict()
         res['versions'] = self.get_versions()
