@@ -13,7 +13,12 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import uuid
+
+import six
+
 from sahara.plugins import utils as u
+from sahara.service.castellan import utils as castellan
 
 
 def get_namenode(cluster):
@@ -32,6 +37,10 @@ def get_oozie(cluster):
     return u.get_instance(cluster, "oozie")
 
 
+def get_spark_history_server(cluster):
+    return u.get_instance(cluster, "spark history server")
+
+
 def get_hiveserver(cluster):
     return u.get_instance(cluster, "hiveserver")
 
@@ -50,3 +59,8 @@ def get_historyserver(cluster):
 
 def get_instance_hostname(instance):
     return instance.hostname() if instance else None
+
+
+def generate_random_password():
+    password = six.text_type(uuid.uuid4())
+    return castellan.store_secret(password)
