@@ -21,7 +21,6 @@ from oslo_log import log as logging
 
 from sahara import conductor as c
 from sahara import context
-from sahara import exceptions as ex
 from sahara.i18n import _
 from sahara.i18n import _LE
 from sahara.i18n import _LW
@@ -37,8 +36,6 @@ conductor = c.API
 LOG = logging.getLogger(__name__)
 
 CONF = cfg.CONF
-CONF.import_opt('api_version', 'sahara.utils.openstack.cinder',
-                group='cinder')
 
 
 def _get_timeout_for_disk_preparing(cluster):
@@ -62,7 +59,7 @@ def _is_xfs_enabled(cluster):
 
 
 def _get_os_distrib(remote):
-    return remote.execute_command('lsb_release -is')[1].strip().lower()
+    return remote.get_os_distrib()
 
 
 def _check_installed_xfs(instance):
@@ -103,141 +100,38 @@ def _can_use_xfs(instances):
     return True
 
 
-def _count_instances_to_attach(instances):
-    result = 0
-    for instance in instances:
-        if instance.node_group.volumes_per_node > 0:
-            result += 1
-    return result
-
-
-def _count_volumes_to_mount(instances):
-    return sum([inst.node_group.volumes_per_node for inst in instances])
-
-
-def attach_to_instances(instances):
-    instances_to_attach = _count_instances_to_attach(instances)
-    if instances_to_attach == 0:
-        mount_to_instances(instances)
-        return
-
-    cpo.add_provisioning_step(
-        instances[0].cluster_id, _("Attach volumes to instances"),
-        instances_to_attach)
-
-    with context.ThreadGroup() as tg:
-        for instance in instances:
-            if instance.node_group.volumes_per_node > 0:
-                with context.set_current_instance_id(instance.instance_id):
-                    tg.spawn(
-                        'attach-volumes-for-instance-%s'
-                        % instance.instance_name, _attach_volumes_to_node,
-                        instance.node_group, instance)
-
-    mount_to_instances(instances)
-
-
-@poll_utils.poll_status(
-    'await_attach_volumes', _("Await for attaching volumes to instances"),
-    sleep=2)
-def _await_attach_volumes(instance, devices):
-    return _count_attached_devices(instance, devices) == len(devices)
-
-
-@cpo.event_wrapper(mark_successful_on_exit=True)
-def _attach_volumes_to_node(node_group, instance):
-    ctx = context.ctx()
-    size = node_group.volumes_size
-    volume_type = node_group.volume_type
-    devices = []
-    for idx in range(1, node_group.volumes_per_node + 1):
-        display_name = "volume_" + instance.instance_name + "_" + str(idx)
-        device = _create_attach_volume(
-            ctx, instance, size, volume_type,
-            node_group.volume_local_to_instance, display_name,
-            node_group.volumes_availability_zone)
-        devices.append(device)
-        LOG.debug("Attached volume {device} to instance".format(device=device))
-
-    _await_attach_volumes(instance, devices)
-
-
-@poll_utils.poll_status(
-    'volume_available_timeout', _("Await for volume become available"),
-    sleep=1)
-def _await_available(volume):
-    volume = cinder.get_volume(volume.id)
-    if volume.status == 'error':
-        raise ex.SystemError(_("Volume %s has error status") % volume.id)
-    return volume.status == 'available'
-
-
-def _create_attach_volume(ctx, instance, size, volume_type,
-                          volume_local_to_instance, name=None,
-                          availability_zone=None):
-    if CONF.cinder.api_version == 1:
-        kwargs = {'size': size, 'display_name': name}
-    else:
-        kwargs = {'size': size, 'name': name}
-
-    kwargs['volume_type'] = volume_type
-    if availability_zone is not None:
-        kwargs['availability_zone'] = availability_zone
-
-    if volume_local_to_instance:
-        kwargs['scheduler_hints'] = {'local_to_instance': instance.instance_id}
-
-    volume = b.execute_with_retries(cinder.client().volumes.create, **kwargs)
-    conductor.append_volume(ctx, instance, volume.id)
-    _await_available(volume)
-
-    resp = b.execute_with_retries(nova.client().volumes.create_server_volume,
-                                  instance.instance_id, volume.id, None)
-    return resp.device
-
-
-def _count_attached_devices(instance, devices):
-    code, part_info = instance.remote().execute_command('cat /proc/partitions')
-
-    count = 0
-    for line in part_info.split('\n')[1:]:
-        tokens = line.split()
-        if len(tokens) > 3:
-            dev = '/dev/' + tokens[3]
-            if dev in devices:
-                count += 1
-
-    return count
-
-
 def mount_to_instances(instances):
     if len(instances) == 0:
         return
 
-    cpo.add_provisioning_step(
-        instances[0].cluster_id,
-        _("Mount volumes to instances"), _count_volumes_to_mount(instances))
-
     use_xfs = _can_use_xfs(instances)
 
     for instance in instances:
         with context.set_current_instance_id(instance.instance_id):
             devices = _find_instance_devices(instance)
-            formatted_devices = []
-            lock = threading.Lock()
-            with context.ThreadGroup() as tg:
-                # Since formating can take several minutes (for large disks)
-                # and can be done in parallel, launch one thread per disk.
-                for device in devices:
-                    tg.spawn('format-device-%s' % device, _format_device,
-                             instance, device, use_xfs, formatted_devices,
-                             lock)
 
-            conductor.instance_update(
-                context.current(), instance,
-                {"storage_devices_number": len(formatted_devices)})
-            for idx, dev in enumerate(formatted_devices):
-                _mount_volume_to_node(instance, idx+1, dev, use_xfs)
+            if devices:
+                cpo.add_provisioning_step(
+                    instance.cluster_id,
+                    _("Mount volumes to {inst_name} instance").format(
+                        inst_name=instance.instance_name), len(devices))
+
+                formatted_devices = []
+                lock = threading.Lock()
+                with context.ThreadGroup() as tg:
+                    # Since formating can take several minutes (for large
+                    # disks) and can be done in parallel, launch one thread
+                    # per disk.
+                    for device in devices:
+                        tg.spawn('format-device-%s' % device, _format_device,
+                                 instance, device, use_xfs, formatted_devices,
+                                 lock)
+
+                conductor.instance_update(
+                    context.current(), instance,
+                    {"storage_devices_number": len(formatted_devices)})
+                for idx, dev in enumerate(formatted_devices):
+                    _mount_volume_to_node(instance, idx+1, dev, use_xfs)
 
 
 def _find_instance_devices(instance):
@@ -249,18 +143,32 @@ def _find_instance_devices(instance):
             "mount | awk '$1 ~ /^\/dev/ {print $1}'")
         mounted_dev = mounted_info.split()
 
-        # filtering attached devices, that should not be mounted
-        for dev in attached_dev[:]:
-            idx = re.sub("\D", "", dev)
-            if idx:
-                if dev in mounted_dev:
-                    attached_dev.remove(re.sub("\d", "", dev))
-                    attached_dev.remove(dev)
+        # find and ignore Nova config drive
+        for label in ("config-2", "CONFIG-2"):
+            code, nova_config_drive = r.execute_command(
+                "/sbin/blkid -t LABEL=\"%s\" -odevice" % label,
+                raise_when_error=False,
+                run_as_root=True
+            )
+            drive_name = nova_config_drive.strip()
+            if code == 0 and drive_name in attached_dev:
+                attached_dev.remove(drive_name)
+                break
 
-        for dev in attached_dev[:]:
-            if re.sub("\D", "", dev):
-                if re.sub("\d", "", dev) in attached_dev:
-                    attached_dev.remove(dev)
+    # filtering attached devices, that should not be mounted
+    for dev in attached_dev[:]:
+        idx = re.sub("\D", "", dev)
+        if idx:
+            if dev in mounted_dev:
+                attached_dev.remove(re.sub("\d", "", dev))
+                attached_dev.remove(dev)
+
+    for dev in attached_dev[:]:
+        if re.sub("\D", "", dev):
+            if re.sub("\d", "", dev) in attached_dev:
+                attached_dev.remove(dev)
+
+    attached_dev = [dev for dev in attached_dev if dev not in mounted_dev]
 
     return attached_dev
 
@@ -287,7 +195,7 @@ def _format_device(
             fs_opts = '-F -m 1 -O dir_index,extents,^has_journal'
             command = 'sudo mkfs.ext4 %s %s' % (fs_opts, device)
             if use_xfs:
-                command = 'sudo mkfs.xfs %s' % device
+                command = 'sudo mkfs.xfs -f %s' % device
             r.execute_command(command, timeout=timeout)
             if lock:
                 with lock:
@@ -296,6 +204,7 @@ def _format_device(
             LOG.warning(
                 _LW("Device {dev} cannot be formatted: {reason}").format(
                     dev=device, reason=e))
+            cpo.add_fail_event(instance, e)
 
 
 def _mount_volume(instance, device_path, mount_point, use_xfs):
