@@ -22,6 +22,7 @@ import testtools
 from sahara import conductor as cond
 from sahara import exceptions as ex
 from sahara.plugins import base as pb
+from sahara.service.castellan import config as castellan
 from sahara.service.edp import job_manager
 from sahara.service.edp import job_utils
 from sahara.service.edp.oozie.workflow_creator import workflow_factory
@@ -29,6 +30,7 @@ from sahara.swift import swift_helper as sw
 from sahara.swift import utils as su
 from sahara.tests.unit import base
 from sahara.tests.unit.service.edp import edp_test_utils as u
+from sahara.utils import cluster as c_u
 from sahara.utils import edp
 from sahara.utils import patches as p
 from sahara.utils import xmlutils
@@ -44,6 +46,7 @@ class TestJobManager(base.SaharaWithDbTestCase):
         super(TestJobManager, self).setUp()
         p.patch_minidom_writexml()
         pb.setup_plugins()
+        castellan.validate_config()
 
     @mock.patch('uuid.uuid4')
     @mock.patch('sahara.utils.remote.get_remote')
@@ -536,12 +539,12 @@ class TestJobManager(base.SaharaWithDbTestCase):
     def test_job_type_supported(self, job_get):
         job, job_exec = u.create_job_exec(edp.JOB_TYPE_PIG)
         job_get.return_value = job
-        self.assertIsNotNone(job_manager._get_job_engine(u.create_cluster(),
-                                                         job_exec))
+        self.assertIsNotNone(job_manager.get_job_engine(u.create_cluster(),
+                                                        job_exec))
 
         job.type = "unsupported_type"
-        self.assertIsNone(job_manager._get_job_engine(u.create_cluster(),
-                                                      job_exec))
+        self.assertIsNone(job_manager.get_job_engine(u.create_cluster(),
+                                                     job_exec))
 
     @mock.patch('sahara.conductor.API.job_get')
     @mock.patch('sahara.conductor.API.job_execution_get')
@@ -553,7 +556,7 @@ class TestJobManager(base.SaharaWithDbTestCase):
         job_get.return_value = job
 
         cluster = u.create_cluster()
-        cluster.status = "Active"
+        cluster.status = c_u.CLUSTER_STATUS_ACTIVE
         cluster_get.return_value = cluster
         with testtools.ExpectedException(ex.EDPError):
             job_manager._run_job(job_exec.id)
@@ -612,7 +615,7 @@ class TestJobManager(base.SaharaWithDbTestCase):
         job_get.return_value = job
 
         cluster = u.create_cluster()
-        cluster.status = "Active"
+        cluster.status = c_u.CLUSTER_STATUS_ACTIVE
         cluster_get.return_value = cluster
 
         time_get.return_value = 10000
@@ -621,3 +624,47 @@ class TestJobManager(base.SaharaWithDbTestCase):
 
         with testtools.ExpectedException(ex.CancelingFailed):
             job_manager.cancel_job(job_exec.id)
+
+    @mock.patch('sahara.conductor.API.job_execution_get')
+    @mock.patch('sahara.conductor.API.cluster_get')
+    @mock.patch('sahara.conductor.API.job_get')
+    @mock.patch(
+        'sahara.service.edp.oozie.engine.OozieJobEngine.run_scheduled_job')
+    def test_scheduled_edp_job_run(self, job_exec_get, cluster_get,
+                                   job_get, run_scheduled_job):
+        configs = {
+            'job_execution_info': {
+                'job_execution_type': 'scheduled',
+                'start': '2015-5-15T01:00Z'
+            }
+        }
+        job, job_exec = u.create_job_exec(edp.JOB_TYPE_PIG, configs)
+        job_exec_get.return_value = job_exec
+        job_get.return_value = job
+
+        cluster = u.create_cluster()
+        cluster.status = "Active"
+        cluster_get.return_value = cluster
+
+        job_manager._run_job(job_exec.id)
+
+        self.assertEqual(1, run_scheduled_job.call_count)
+
+    @mock.patch('sahara.conductor.API.job_get')
+    @mock.patch('sahara.conductor.API.job_execution_get')
+    @mock.patch('sahara.conductor.API.cluster_get')
+    @mock.patch('sahara.service.edp.base_engine.JobEngine.suspend_job')
+    def test_suspend_unsuspendible_job(self, suspend_job_get,
+                                       cluster_get, job_exec_get, job_get):
+        info = {
+            'status': edp.JOB_STATUS_SUCCEEDED
+        }
+        job, job_exec = u.create_job_exec(edp.JOB_TYPE_PIG, None, False, info)
+        job_exec_get.return_value = job_exec
+        job_get.return_value = job
+
+        cluster = u.create_cluster()
+        cluster.status = "Active"
+        cluster_get.return_value = cluster
+
+        self.assertEqual(0, suspend_job_get.call_count)
